RowTransform

Trait RowTransform 

pub trait RowTransform: Send {
    // Required method
    fn transform_row(&self, src: &[u8], dst: &mut [u8], width: u32);
}
Row-level color transform produced by a ColorManagement implementation.

Applies an ICC-to-ICC color conversion to a row of pixel data.

Required Methods

fn transform_row(&self, src: &[u8], dst: &mut [u8], width: u32)

Transform one row of pixels from source to destination color space.

src and dst may be different lengths if the transform changes the pixel format (e.g., CMYK to RGB). width is the number of pixels, not bytes.

Implementors